function cellInfo = ParamsBus(varargin) 
% PARAMSBUS returns a cell array containing bus object information 
% 
% Optional Input: 'false' will suppress a call to Simulink.Bus.cellToObject 
%                 when the MATLAB file is executed. 
% The order of bus element attributes is as follows:
%   ElementName, Dimensions, DataType, SampleTime, Complexity, SamplingMode, DimensionsMode 

suppressObject = false; 
if nargin == 1 && islogical(varargin{1}) && varargin{1} == false 
    suppressObject = true; 
elseif nargin > 1 
    error('Invalid input argument(s) encountered'); 
end 

cellInfo = { ... 
  { ... 
    'AmplPhase', ... 
    '', ... 
    sprintf(''), { ... 
      {'Ampl', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'Phase', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
    } ...
  } ...
  { ... 
    'CouplerParams', ... 
    '', ... 
    sprintf(''), { ... 
      {'g11', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'g21', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
    } ...
  } ...
  { ... 
    'ModulatorParams', ... 
    '', ... 
    sprintf(''), { ... 
      {'eta', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'Vpi_AC', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'Vpi_DC', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'Vb', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'alpha', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'P0', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
    } ...
  } ...
  { ... 
    'OEOparams', ... 
    '', ... 
    sprintf(''), { ... 
      {'carrierFrequency', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'ExtraFilterLoss', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'flickerSigma', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'Coupler', 1, 'Bus: CouplerParams', -1, 'real', 'Sample', 'Fixed'}; ...
      {'NF', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'rhoDC', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'rhoAC', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'R', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'fiberDelay', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
      {'OptModParams', 1, 'Bus: ModulatorParams', -1, 'real', 'Sample', 'Fixed'}; ...
      {'T', 1, 'double', -1, 'real', 'Sample', 'Fixed'}; ...
    } ...
  } ...
}'; 

if ~suppressObject 
    % Create bus objects in the MATLAB base workspace 
    Simulink.Bus.cellToObject(cellInfo) 
end 
